//+------------------------------------------------------------------------+
//|                                                                        |
//| Double Long.mq4                                                        |
//| Copyright  2007 by Marc Tardif                                        |
//| mdt38@rogers.com                                                       |
//| http://www.inlinetrader.com/?RefID=Freedom38                           |
//| Last modified by Marc Tardif on December 6, 2007                       |
//|                                                                        |
//| For running on Interbank FX mini account.                              |
//|                                                                        |
//| Strategy:                                                              |
//| 1. Always have two long positions open.                                |
//|    - 1st position: TP +100, SL -50.                                    |
//|    - 2nd position: TP +100, SL -100.                                   |
//|                                                                        |
//+------------------------------------------------------------------------+
#property copyright "Copyright  2007 Marc Tardif"
#property link      "http://www.inlinetrader.com/?RefID=Freedom38"

extern int TakeProfitPips = 100;
extern int StopLossPips = 50;
extern double LotRatio = 1.00;             // Ratio of lot size to lot value.
extern int Slippage = 5;                   // Maximum slippage (in pips) when opening positions.
extern int SystemNumber = 20071206;        // Number used to identify positions generated by this system.
extern string SystemName = "DoubleLong";  // Comment used to identify positions generated by this system.

//---- Variables related to Money Management.
double LotValue = 0;                       // Lot value (contract size) of current symbol.
double TickValue = 0;                      // Tick value of current symbol.
double Delta = 0;                          // Fixed ratio money management delta.
double TradeLots = 0;                      // Number of lots to trade when opening new position.

//---- Variables related to position management.
int Counter = 0;                           // Counter for "for" loops.
int OpenOrders = 0;                        // Number of open positions.
int OpenLongOrders = 0;                    // Number of open long positions.
int OpenShortOrders = 0;                   // Number of open short positions.
double Spread = 0;                         // Bid/Ask spread.
double SL = 0;                             // Stop Loss.
double TP = 0;                             // Take Profit.


//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
   //---- Determine Lot Value (Contract Size) for current symbol.
   LotValue = MarketInfo(Symbol(), MODE_LOTSIZE);
   
   //---- Determine Tick value for current symbol.
   //---- Tick value will be exact for symbols where the second currency matches
   //---- the account currency (for example, account in USD and symbol is GBPUSD).
   //---- Tick value will be approximate for symbols where the second currency does
   //---- not match the account currency (for example, account in USD and symbol is USDCAD).
   TickValue = MarketInfo(Symbol(), MODE_TICKVALUE);
   
   //---- Record the fixed ratio money management delta.
   //---- The delta represents the increase in equity required to increase the
   //---- size of trade lots by 1 whole lot.
   Delta = NormalizeDouble(LotValue/LotRatio, 2);

   return(0);
  }

  
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
   return(0);
  }


//+---------------------------------------------------------------------+
//| Fixed ratio money management to determine lot size.                 |
//| Each 1% change in account equity causes 1% change in lot size.      |
//+---------------------------------------------------------------------+
double LotSize (double CurrentEquity)
  {
   double NewLots = 0;
   NewLots = NormalizeDouble(CurrentEquity/LotValue*LotRatio, 2);   
   return(NewLots);
  }


//+------------------------------------------------------------------+
//| Expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
   //---- Record the Bid/Ask spread.
   Spread = (Ask - Bid);

   //---- Reset variables related to position management.  
   OpenOrders = 0;
   OpenLongOrders = 0;
   OpenShortOrders = 0;

   
   //---- Count number of open positions generated by this expert advisor.
   for(Counter = 0; Counter < OrdersTotal(); Counter++)   
     {
       OrderSelect(Counter, SELECT_BY_POS, MODE_TRADES);

       if (OrderMagicNumber() == SystemNumber)
         {
	  	    OpenOrders++;
	  	    
	  	    if (OrderType() == OP_BUY)
            OpenLongOrders++;

	  	    if (OrderType() == OP_SELL)
            OpenShortOrders++;
         }       
     }


   //---- Enter long positions if none currently exist. 
   if (OpenLongOrders == 0) 
     {
      TradeLots = LotSize(AccountEquity());
      SL = Ask - (StopLossPips*Point);
      TP = Ask + (TakeProfitPips*Point);
      OrderSend (Symbol(), OP_BUY, TradeLots, Ask, Slippage, SL, TP, SystemName, SystemNumber, 0, Blue);

      SL = Ask - (TakeProfitPips*Point);
      OrderSend (Symbol(), OP_BUY, TradeLots, Ask, Slippage, SL, TP, SystemName, SystemNumber, 0, Blue);

      OpenOrders = 2;
      OpenLongOrders = 2;
     }

   return(0);
  }
//+------------------------------------------------------------------+